@@ -31,9 +31,13 @@ from openlineage.client.utils import RedactMixin
 from packaging.version import Version
 
 from airflow import __version__ as AIRFLOW_VERSION
-from airflow.datasets import Dataset
-from airflow.exceptions import AirflowProviderDeprecationWarning  # TODO: move this maybe to Airflow's logic?
+from airflow.exceptions import (
+    AirflowProviderDeprecationWarning,
+)
+
+# TODO: move this maybe to Airflow's logic?
 from airflow.models import DAG, BaseOperator, DagRun, MappedOperator
+from airflow.providers.common.compat.assets import Asset
 from airflow.providers.openlineage import conf
 from airflow.providers.openlineage.plugins.facets import (
     AirflowDagRunFacet,
@@ -51,7 +55,12 @@ from airflow.providers.openlineage.utils.selective_enable import (
 )
 from airflow.serialization.serialized_objects import SerializedBaseOperator
 from airflow.utils.context import AirflowContextDeprecationWarning
-from airflow.utils.log.secrets_masker import Redactable, Redacted, SecretsMasker, should_hide_value_for_key
+from airflow.utils.log.secrets_masker import (
+    Redactable,
+    Redacted,
+    SecretsMasker,
+    should_hide_value_for_key,
+)
 from airflow.utils.module_loading import import_string
 
 if TYPE_CHECKING:
@@ -283,8 +292,8 @@ class TaskInstanceInfo(InfoJsonEncodable):
     }
 
 
-class DatasetInfo(InfoJsonEncodable):
-    """Defines encoding Airflow Dataset object to JSON."""
+class AssetInfo(InfoJsonEncodable):
+    """Defines encoding Airflow Asset object to JSON."""
 
     includes = ["uri", "extra"]
 
@@ -335,8 +344,8 @@ class TaskInfo(InfoJsonEncodable):
             if hasattr(task, "task_group") and getattr(task.task_group, "_group_id", None)
             else None
         ),
-        "inlets": lambda task: [DatasetInfo(i) for i in task.inlets if isinstance(i, Dataset)],
-        "outlets": lambda task: [DatasetInfo(o) for o in task.outlets if isinstance(o, Dataset)],
+        "inlets": lambda task: [AssetInfo(i) for i in task.inlets if isinstance(i, Asset)],
+        "outlets": lambda task: [AssetInfo(o) for o in task.outlets if isinstance(o, Asset)],
     }
 
 
@@ -473,7 +482,6 @@ def _get_task_groups_details(dag: DAG) -> dict:
     return {
         tg_id: {
             "parent_group": tg.parent_group.group_id,
-            "tooltip": tg.tooltip,
             "ui_color": tg.ui_color,
             "ui_fgcolor": tg.ui_fgcolor,
             "ui_label": tg.label,
@@ -497,7 +505,11 @@ def _emits_ol_events(task: BaseOperator | MappedOperator) -> bool:
     )
 
     emits_ol_events = all(
-        (config_selective_enabled, not config_disabled_for_operators, not is_skipped_as_empty_operator)
+        (
+            config_selective_enabled,
+            not config_disabled_for_operators,
+            not is_skipped_as_empty_operator,
+        )
     )
     return emits_ol_events
 
@@ -563,7 +575,12 @@ class OpenLineageRedactor(SecretsMasker):
                             setattr(
                                 item,
                                 dict_key,
-                                self._redact(subval, name=dict_key, depth=(depth + 1), max_depth=max_depth),
+                                self._redact(
+                                    subval,
+                                    name=dict_key,
+                                    depth=(depth + 1),
+                                    max_depth=max_depth,
+                                ),
                             )
                     return item
                 elif is_json_serializable(item) and hasattr(item, "__dict__"):
@@ -574,7 +591,12 @@ class OpenLineageRedactor(SecretsMasker):
                             setattr(
                                 item,
                                 dict_key,
-                                self._redact(subval, name=dict_key, depth=(depth + 1), max_depth=max_depth),
+                                self._redact(
+                                    subval,
+                                    name=dict_key,
+                                    depth=(depth + 1),
+                                    max_depth=max_depth,
+                                ),
                             )
                     return item
                 else:
@@ -637,23 +659,37 @@ def normalize_sql(sql: str | Iterable[str]):
 def should_use_external_connection(hook) -> bool:
     # If we're at Airflow 2.10, the execution is process-isolated, so we can safely run those again.
     if not IS_AIRFLOW_2_10_OR_HIGHER:
-        return hook.__class__.__name__ not in ["SnowflakeHook", "SnowflakeSqlApiHook", "RedshiftSQLHook"]
+        return hook.__class__.__name__ not in [
+            "SnowflakeHook",
+            "SnowflakeSqlApiHook",
+            "RedshiftSQLHook",
+        ]
     return True
 
 
-def translate_airflow_dataset(dataset: Dataset, lineage_context) -> OpenLineageDataset | None:
+def translate_airflow_asset(asset: Asset, lineage_context) -> OpenLineageDataset | None:
     """
-    Convert a Dataset with an AIP-60 compliant URI to an OpenLineageDataset.
+    Convert an Asset with an AIP-60 compliant URI to an OpenLineageDataset.
 
-    This function returns None if no URI normalizer is defined, no dataset converter is found or
+    This function returns None if no URI normalizer is defined, no asset converter is found or
     some core Airflow changes are missing and ImportError is raised.
     """
     try:
-        from airflow.datasets import _get_normalized_scheme
+        from airflow.assets import _get_normalized_scheme
+    except ModuleNotFoundError:
+        try:
+            from airflow.datasets import _get_normalized_scheme  # type: ignore[no-redef, attr-defined]
+        except ImportError:
+            return None
+
+    try:
         from airflow.providers_manager import ProvidersManager
 
-        ol_converters = ProvidersManager().dataset_to_openlineage_converters
-        normalized_uri = dataset.normalized_uri
+        ol_converters = getattr(ProvidersManager(), "asset_to_openlineage_converters", None)
+        if not ol_converters:
+            ol_converters = ProvidersManager().dataset_to_openlineage_converters  # type: ignore[attr-defined]
+
+        normalized_uri = asset.normalized_uri
     except (ImportError, AttributeError):
         return None
 
@@ -666,4 +702,4 @@ def translate_airflow_dataset(dataset: Dataset, lineage_context) -> OpenLineageD
     if (airflow_to_ol_converter := ol_converters.get(normalized_scheme)) is None:
         return None
 
-    return airflow_to_ol_converter(Dataset(uri=normalized_uri, extra=dataset.extra), lineage_context)
+    return airflow_to_ol_converter(Asset(uri=normalized_uri, extra=asset.extra), lineage_context)
